@@ -24,17 +24,28 @@ def get_tables(schema, engine):
     insp = inspect(engine)
     return insp.get_table_names(schema)
 
-def drop_table(table, schema, engine):
+def drop_table(table, schema, engine, close_connection = True):
     conn = engine.connect()
     conn.execute(f'DROP TABLE IF EXISTS {schema}.{table};')
-    conn.close()
+    if close_connection:
+        conn.close()
 
-def delete_table(table_name, schema, engine):
+def delete_table(table_name, schema, engine, close_connection = True):
     conn = engine.connect()
     conn.execute(f'DELETE FROM {schema}.{table_name}')
-    conn.close()
+    if close_connection:
+        conn.close()
 
-def drop_schema(schema, engine):
+def drop_schema(schema, engine, close_connection = True):
     conn = engine.connect()
     conn.execute(f'DROP SCHEMA {schema}')
-    conn.close()
\ No newline at end of file
+    if close_connection:
+        conn.close()
+
+def apply_delete_to_schema(schema, engine, close_connection = True):
+    conn = engine.connect()
+    tables = get_tables(schema, engine)
+    for i in tables:
+        delete_table(i, schema, engine)
+    if close_connection:
+        conn.close()
\ No newline at end of file
